@@ -98,7 +98,7 @@ class Domoticz(IPlugin):
 #				log.msg("resp  :  %s" % (req))				
 				log.msg("resp  :  %s" % (resp))
 				log.msg("response   :  %s" % (jsonreq))
-				log.msg("*********************************************  : )
+				log.msg("*********************************************  : ")
 				log.msg("jsonreq.result :  %s" % (jsonreq['result']))
 				len = len(jsonreq['result'])
 				log.msg(" len len   :  %s" % (len))	
